@@ -24,7 +24,7 @@
 #include <config.h>
 #include <libgnome/gnome-macros.h>
 
-#ifndef GNOME_DISABLE_DEPRECATED_SOURCE
+#if !defined(GNOME_DISABLE_DEPRECATED_SOURCE) && !defined(GTK_DISABLE_DEPRECATED)
 
 #include <gtk/gtk.h>
 #include <gdk/gdk.h>
@@ -47,8 +47,7 @@ static GtkWidget  *gnome_mdi_generic_child_set_label        (GnomeMDIGenericChil
 							     GtkWidget *old_label);
 
 GNOME_CLASS_BOILERPLATE (GnomeMDIGenericChild, gnome_mdi_generic_child,
-			 GnomeMDIChild, gnome_mdi_child,
-			 GNOME_TYPE_MDI_CHILD)
+						 GnomeMDIChild, GNOME_TYPE_MDI_CHILD)
 
 static void gnome_mdi_generic_child_class_init (GnomeMDIGenericChildClass *klass)
 {
@@ -105,7 +104,7 @@ GnomeMDIGenericChild *gnome_mdi_generic_child_new (const gchar *name)
 {
 	GnomeMDIGenericChild *child;
 
-	child = gtk_type_new (GNOME_TYPE_MDI_GENERIC_CHILD);
+	child = g_object_new (GNOME_TYPE_MDI_GENERIC_CHILD, NULL);
 
 	GNOME_MDI_CHILD(child)->name = g_strdup(name);
 
@@ -425,4 +424,4 @@ static void gnome_mdi_generic_child_destroy (GtkObject *obj)
 		(* GTK_OBJECT_CLASS(parent_class)->destroy)(obj);
 }
 
-#endif /* GNOME_DISABLE_DEPRECATED_SOURCE */
+#endif /* !defined(GNOME_DISABLE_DEPRECATED_SOURCE) && !defined(GTK_DISABLE_DEPRECATED) */
